@@ -9,7 +9,7 @@ def Fibonacci(n):
         n1 = n2
         n2 = n3
         count += 1
-    print(sequenceList[n-1])
+    return sequenceList[n-1]
 
 
 Fibonacci()
\ No newline at end of file
